@@ -22,6 +22,7 @@ affinity <- function(...,property=NULL,sout=NULL,exceed.Ttr=FALSE,
   args <- c(args,list(sout=sout,exceed.Ttr=exceed.Ttr))
 
   # the species we're given
+  thermo <- get("thermo")
   mybasis <- thermo$basis
   myspecies <- thermo$species
 
@@ -48,6 +49,7 @@ affinity <- function(...,property=NULL,sout=NULL,exceed.Ttr=FALSE,
       # account for protein activities later
       resprot <- paste(resnames,"RESIDUE",sep="_")
       species(resprot, 0)
+      thermo <- get("thermo", "CHNOSZ")
       ires <- match(resprot, thermo$species$name)
     }
 
@@ -59,6 +61,7 @@ affinity <- function(...,property=NULL,sout=NULL,exceed.Ttr=FALSE,
       msgout('affinity: loading buffer species\n')
       if(!is.null(thermo$species)) is.species <- 1:nrow(thermo$species) else is.species <- numeric()
       is.buffer <- buffer(logK=NULL)
+      thermo <- get("thermo", "CHNOSZ")
       is.buff <- numeric()
       for(i in 1:length(is.buffer)) is.buff <- c(is.buff,as.numeric(is.buffer[[i]]))
       is.only.buffer <- is.buff[!is.buff %in% is.species]
